=======
Credits
=======

Development Lead
----------------

* Ivan Ven Osdel <ivan@wimpyanalytics.com>

Contributors
------------

* Mikko Ohtamaa <mikko@opensourcehacker.com>
* Brad Montgomery <brad@bradmontgomery.net>
* Samuel Mendes <smendes@webgeoservices.com>
